#
# spec file for package python-textual
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-textual
Version:        1.0.0
Release:        1.3
Summary:        TUI framework for Python
License:        MIT
URL:            https://github.com/Textualize/textual
Source:         https://files.pythonhosted.org/packages/source/t/textual/textual-%{version}.tar.gz
#
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
# SECTION runtime requirements
BuildRequires:  %{python_module markdown-it-py >= 2.1.0}
BuildRequires:  %{python_module linkify-it-py}
BuildRequires:  %{python_module platformdirs >= 3.6.0 with %python-platformdirs < 5}
BuildRequires:  %{python_module rich >= 13.3.3}
BuildRequires:  %{python_module typing-extensions >= 4.4.0 with %python-typing-extensions < 5}
# /SECTION
# SECTION test requirements
BuildRequires:  %{python_module pytest >= 8.3.1}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest-xdist >= 3.6.1}
BuildRequires:  %{python_module tree-sitter}
# /SECTION
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
#
Requires:       python-markdown-it-py >= 2.1.0
Requires:       python-rich >= 13.3.3
Requires:       (python-platformdirs >= 3.6.0 with python-platformdirs < 5)
Requires:       (python-typing-extensions >= 4.4.0 with python-typing-extensions < 5)
Suggests:       python-tree-sitter
Suggests:       python-tree-sitter-languages
BuildArch:      noarch
%python_subpackages

%description
Textual is a Python framework for creating interactive applications
that run in your terminal.

It adds interactivity to Rich with a Python API inspired by modern
web development.

On modern terminal software (installed by default on most systems),
Textual apps can use 16.7 million colors with mouse support and
smooth flicker-free animation. A layout engine and re-usable
components make it possible to build apps that resemble the desktop
and web experience.

%prep
%autosetup -n textual-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# fixture 'snap_compare' not found
rm -f tests/snapshot_tests/test_snapshots.py
IGNORED_CHECKS="test_textual_env_var"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_allow_focus"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_focus_chain"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_focus_next_and_previous"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_focus_next_and_previous_with_str_selector"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_focus_next_and_previous_with_str_selector_without_self"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_focus_next_and_previous_with_type_selector"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_focus_next_and_previous_with_type_selector_without_self"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_focus_next_wrap_around"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_focus_previous_wrap_around"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_language_binary_missing"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_message_sender_from_reactive"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_no_focus_empty_selector"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_register_language"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_register_language_existing_language"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_wrap_around_selector"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_setting_unknown_language"
IGNORED_CHECKS="${IGNORED_CHECKS} or test_update_highlight_query"
%pytest -k "not (${IGNORED_CHECKS})"

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/textual
%{python_sitelib}/textual-%{version}*-info

%changelog
* Sun Feb 16 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 1.0.0:
  * Added
  - Added App.clipboard #5352
  - Added standard cut/copy/paste (ctrl+x, ctrl+c, ctrl+v)
    bindings to Input / TextArea #5352 & #5374
  - Added system boolean to Binding, which hides the binding from
    the help panel #5352
  - Added support for double/triple/etc clicks via chain
    attribute on Click events #5369
  - Added times parameter to Pilot.click method, for simulating
    rapid clicks #5369
  - Text can now be select using mouse or keyboard in the Input
    widget #5340
  * Changed
  - Breaking change: Change default quit key to ctrl+q #5352
  - The command palette will now select the top item
    automatically #5361
  - ctrl+shift+k now deletes the current line in TextArea, and
    ctrl+x will cut
  - the selection if there is one, otherwise it will cut the
    current line #5374
  - Implemented a better matching algorithm for the command
    palette #5365
  * Fixed
  - Fixed issue with alignment in auto containers #5360
* Sun Feb 16 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.89.1:
  * Fixed
  - Fixed alignment of docked widgets #5347
* Sun Feb 16 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.89.0:
  * Added
  - Added "tab" border style #5335
  - Added support for XML syntax highlighting #5320
  - Added TextArea.update_highlight_query #5320
  * Fixed
  - Fixed Select not scrolling highlight in to view when clicked
    [#5255]
  - Upgraded tree-sitter to 0.23+ (syntax extras) #5320
  - Some syntax highlighting changes due to tree-sitter updates
    [#5320]
  - Breaking change: Document.query_syntax_tree signature changed
    [#5320]
  - Breaking change: TextArea.register_language signature changed
    [#5320]
  - Breaking change: SyntaxAwareDocument.language_name property
    removed #5320
  - Breaking change: Kotlin syntax highlighting removed from
    TextArea #5320
  - Fixed selection list wrapping #5331
  - Fixed CSS encoding issue on Windows #5324
* Mon Jan 20 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- ignore some more tests that are failing now, possibly due to
  updated dependencies
* Mon Dec  2 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package python-textual, required by python-grummage
